@@ -484,14 +484,19 @@ class RKXMLRequest(XMLRequest):
             order_item = order.attrib
             for dish in order.findall('./Session/Dish'):
                 attr_of_item_node = dish.attrib
-                for modi in order.findall('./Session/Dish/Modi'):
+                modifications = []
+
+                for modi in dish.findall('./Modi'):
                     modi_item = modi.attrib
-                    order_obj = OrderLineDTO(
+                    modifications.append(modi_item.get('name'))
+
+                order_obj = OrderLineDTO(
                         order_guid=order_item.get('guid'),
                         line_guid=attr_of_item_node.get('line_guid'),
                         dish_id=attr_of_item_node.get('id'),
                         dish_name=attr_of_item_node.get('name'),
                         quantity=int(attr_of_item_node.get('quantity')) / 1000,
-                        modi=modi_item.get('name'))
-                    element_list.append(order_obj)
+                        modi=', '.join(modifications))
+
+                element_list.append(order_obj)
         return element_list
